accumulate_img_bands_to_list: accumulate bands to list

View source: R/ee_accumulate_band_ic.R

accumulate_img_bands_to_listR Documentation

accumulate bands to list

Description

Function to be used with rgee iterate to return a list of images containing the image

Usage

accumulate_img_bands_to_list(img, lst)

Arguments

img

ee Image class object

lst

list containing first img to iterate over

Value

ee List of images with each item containing the successive accumulation of


impact-initiatives-geospatial/easyrgee documentation built on March 26, 2022, 10:42 p.m.