View source: R/ee_accum_reduce_to_doy.R
| ee_accum_reduce_to_doy | R Documentation |
creates day of year image/raster based on an accumulation threshold
ee_accum_reduce_to_doy(ic, thresh, band)
ic |
an ee ImageCollection |
thresh |
accumulation threshold |
band |
band to accumulate |
user should carefully decide start and end date for accumulation. This is currently really only designed for assessing seasonal accumulations
and ee image/raster the contains the first date (DOY) the accumulation threshold was met per pixel.
## Not run:
# load libraries
library(easyrgee)
library(rgee)
ee_Initialize()
chirps <- ee$ImageCollection("UCSB-CHG/CHIRPS/DAILY")$filterDate("2016-01-01","2016-12-31")
precip_cumulative<- ee_accumulate_band_ic(ic = chirps, band = "precipitation")
#visualize
Map$addLayer(precip_threshold_doy,
visParams = list(min=0,
max=365,
palette=c('#9ecae1,
#ffffff,
#ffeda0,
#feb24c,
#f03b20'))
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.