ee_accumulate_band_ic: accumulate_ic_band

View source: R/ee_accumulate_band_ic.R

ee_accumulate_band_icR Documentation

accumulate_ic_band

Description

Creates a cumulative precipitation rgee ee$ImageCollection with each all pixels in each consecutive image containing the sum of all previous values

Usage

ee_accumulate_band_ic(ic, band)

Arguments

ic

ee$ImageCollection object with user-defined start and end-date

band

band to accumulate value from

Details

user should carefully decide start and end date for accumulation. This is currently really only designed for assessing seasonal accumulations

Value

returns ee$ImageCollection with each contained image containing the successive addition/accumulation of pixel-level values of chosen band.

Examples

## Not run: 

# load libraries
library(easyrgee)
library(rgee)
ee_Initialize()

chirps <-  ee$ImageCollection("UCSB-CHG/CHIRPS/DAILY")$filterDate("2016-01-01","2016-12-31")
precip_cumulative<- ee_accumulate_band_ic(ic = chirps, band = "precipitation")


## End(Not run)

impact-initiatives-geospatial/easyrgee documentation built on March 26, 2022, 10:42 p.m.