ic_join_bands: ic_join_bands

View source: R/ic_join_bands.R

ic_join_bandsR Documentation

ic_join_bands

Description

ic_join_bands

Usage

ic_join_bands(x, y, by)

Arguments

x, y

A pair of ImageCollections

by

A character vector of variables to join by.

Value

An object of the same type as x. The output has the following properties: Same number of images as x Total number of bands equal the number of bands in x plus the number of bands in y


impact-initiatives-geospatial/easyrgee documentation built on March 26, 2022, 10:42 p.m.