View source: R/ee_accumulate_band_ic.R
| ee_accumulate_band_ic | R Documentation |
Creates a cumulative precipitation rgee ee$ImageCollection with each all pixels in each consecutive image containing the sum of all previous values
ee_accumulate_band_ic(ic, band)
ic |
|
band |
band to accumulate value from |
user should carefully decide start and end date for accumulation. This is currently really only designed for assessing seasonal accumulations
returns ee$ImageCollection with each contained image containing the successive addition/accumulation of pixel-level values of chosen band.
## Not run:
# load libraries
library(easyrgee)
library(rgee)
ee_Initialize()
chirps <- ee$ImageCollection("UCSB-CHG/CHIRPS/DAILY")$filterDate("2016-01-01","2016-12-31")
precip_cumulative<- ee_accumulate_band_ic(ic = chirps, band = "precipitation")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.