View source: R/ic_join_bands.R
| ic_join_bands | R Documentation |
ic_join_bands
ic_join_bands(x, y, by)
x, y |
A pair of ImageCollections |
by |
A character vector of variables to join by. |
An object of the same type as x. The output has the following properties:
Same number of images as x
Total number of bands equal the number of bands in x plus the number of bands in y
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.